@@ -662,22 +662,22 @@ class MotuMixer(QWidget, Ui_MotuMixerUI):
             self.mix4_tab.setTabEnabled(1, False)  # AES/EBU
         if (self.sample_rate > 48000):
             log.debug("Disabling controls not present above 48 kHz")
-            self.mix1_adat5.setEnabled(False)
-            self.mix1_adat6.setEnabled(False)
-            self.mix1_adat7.setEnabled(False)
-            self.mix1_adat8.setEnabled(False)
-            self.mix2_adat5.setEnabled(False)
-            self.mix2_adat6.setEnabled(False)
-            self.mix2_adat7.setEnabled(False)
-            self.mix2_adat8.setEnabled(False)
-            self.mix3_adat5.setEnabled(False)
-            self.mix3_adat6.setEnabled(False)
-            self.mix3_adat7.setEnabled(False)
-            self.mix3_adat8.setEnabled(False)
-            self.mix4_adat5.setEnabled(False)
-            self.mix4_adat6.setEnabled(False)
-            self.mix4_adat7.setEnabled(False)
-            self.mix4_adat8.setEnabled(False)
+            self.mix1adat5.setEnabled(False)
+            self.mix1adat6.setEnabled(False)
+            self.mix1adat7.setEnabled(False)
+            self.mix1adat8.setEnabled(False)
+            self.mix2adat5.setEnabled(False)
+            self.mix2adat6.setEnabled(False)
+            self.mix2adat7.setEnabled(False)
+            self.mix2adat8.setEnabled(False)
+            self.mix3adat5.setEnabled(False)
+            self.mix3adat6.setEnabled(False)
+            self.mix3adat7.setEnabled(False)
+            self.mix3adat8.setEnabled(False)
+            self.mix4adat5.setEnabled(False)
+            self.mix4adat6.setEnabled(False)
+            self.mix4adat7.setEnabled(False)
+            self.mix4adat8.setEnabled(False)
 
         # Ensure the correct input controls are active for a given interface.
         # Only the Ultralite has phase inversion switches.
@@ -703,9 +703,10 @@ class MotuMixer(QWidget, Ui_MotuMixerUI):
         self.disable_hide(self.ana6_pad)
         self.disable_hide(self.ana7_pad)
         self.disable_hide(self.ana8_pad)
-        # The Traveler has level and boost switchs for analog 5-8.  The Ultralite
-        # doesn't implement them.  All other interfaces have them over analog 1-8.
-        if (self.model==MOTU_MODEL_TRAVELER or self.model==MOTU_MODEL_ULTRALITE):
+        # The Traveler has level and boost switchs for analog 5-8.  The 
+        # Ultralite and 896HD don't implement them.  All other interfaces have
+        # them over analog 1-8.
+        if (self.model==MOTU_MODEL_TRAVELER or self.model==MOTU_MODEL_ULTRALITE or self.model==MOTU_MODEL_896HD):
             self.disable_hide(self.ana1_level)
             self.disable_hide(self.ana2_level)
             self.disable_hide(self.ana3_level)
@@ -714,7 +715,7 @@ class MotuMixer(QWidget, Ui_MotuMixerUI):
             self.disable_hide(self.ana2_boost)
             self.disable_hide(self.ana3_boost)
             self.disable_hide(self.ana4_boost)
-        if (self.model == MOTU_MODEL_ULTRALITE):
+        if (self.model==MOTU_MODEL_ULTRALITE or self.model==MOTU_MODEL_896HD):
             self.disable_hide(self.ana5_level)
             self.disable_hide(self.ana6_level)
             self.disable_hide(self.ana7_level)
